{% extends 'page.html' %} {% block meta %}{% endblock %} {% block page_title %}

# {{ _("History of %(title)s", title=title) }}

{% endblock %} {% block title %}{{ _("History of %(title)s", title=title) }} - {{ wiki.site_name }}{% endblock %} {% block content %}

{{ _("History of changes for %(link)s.", link=page.wiki_link(title)|safe) }}

{% for date, date_url, rev, author, comment in history %}
- {{ date_html(date)|safe }} {% if edit_url %} {% endif %} . . . . {{ page.wiki_link('~%s' % author, author)|safe }}
  {{ comment }}
{% endfor %}

{% endblock %}